use super::*;
use crate::SqliteReferenceStore;

async fn create_sqlite_store() -> SqliteReferenceStore {
    SqliteReferenceStore::new("sqlite::memory:").await.unwrap()
}

#[tokio::test]
async fn test_store_and_retrieve_reference() {
    let store = create_sqlite_store().await;
    test_store_and_retrieve_reference_impl(&store).await;
}

#[tokio::test]
async fn test_store_and_retrieve_content() {
    let store = create_sqlite_store().await;
    test_store_and_retrieve_content_impl(&store).await;
}

#[tokio::test]
async fn test_reference_with_dependents() {
    let store = create_sqlite_store().await;
    test_reference_with_dependents_impl(&store).await;
}

#[tokio::test]
async fn test_get_graph() {
    let store = create_sqlite_store().await;
    test_get_graph_impl(&store).await;
}

#[tokio::test]
async fn test_nonexistent_reference() {
    let store = create_sqlite_store().await;
    test_nonexistent_reference_impl(&store).await;
}

#[tokio::test]
async fn test_nonexistent_content() {
    let store = create_sqlite_store().await;
    test_nonexistent_content_impl(&store).await;
}

#[tokio::test]
async fn test_reference_without_content_address() {
    let store = create_sqlite_store().await;
    test_reference_without_content_address_impl(&store).await;
}

#[tokio::test]
async fn test_schema_version_management() {
    let store = create_sqlite_store().await;

    // Verify the schema version is correctly set
    let version = store.get_current_schema_version().await.unwrap();
    assert_eq!(version, 1, "Schema version should be 1");

    // Verify we can still perform basic operations
    let reference = Reference::new(
        Some("test_content".to_string()),
        "test_schema_version".to_string(),
    );

    store.store_reference(&reference).await.unwrap();
    let retrieved = store.get_reference(&reference.id).await.unwrap();
    assert_eq!(retrieved.name, reference.name);
}
